# -*- coding: utf-8
from django.contrib import admin

from . import models


class ArticleAdmin(admin.ModelAdmin):
    model = models.Article
    list_display = ('source', 'identifier', 'user', 'active', 'created', 'modified')
    raw_id_fields = ('user', )
    search_fields = ('user__username', 'identifier', 'description')
    list_filter = ('active', 'source', )
    save_as = True


admin.site.register(models.Article, ArticleAdmin)



# -*- coding: utf-8 -*-
from rest_framework import routers

from . import viewsets


app_name = 'literature_knowledgebase'
router = routers.SimpleRouter()
router.register(r'', viewsets.ArticleViewSet)

default_router = routers.DefaultRouter()
default_router.register(r'articles', viewsets.ArticleViewSet)


urlpatterns = default_router.urls



# -*- coding: utf-8 -*-
from django.db.models import CharField

import django_filters
from genomix.filters import DisplayChoiceFilter

from . import choices, models


class ArticleFilter(django_filters.rest_framework.FilterSet):

    username = django_filters.CharFilter(
        name='user__username',
        lookup_expr='iexact',
    )
    source = DisplayChoiceFilter(choices=choices.SOURCES)

    class Meta:
        model = models.Article
        fields = [
            'source',
            'identifier',
            'user',
            'username',
            'active',
            'description',
        ]
        filter_overrides = {
            CharField: {
                'filter_class': django_filters.CharFilter,
                'extra': lambda f: {
                    'lookup_expr': 'icontains',
                },
            }
        }



from graphene import Node, String
from graphene_django import DjangoObjectType

from . import choices, models


class ArticleNode(DjangoObjectType):

    source = String()
    article_url = String()
    fetch_url = String()
    summary_url = String()

    class Meta:
        model = models.Article
        interfaces = (Node, )

    def resolve_type(self, info):
        return choices.SOURCES[self.type]

    def article_url(self, info):
        return self.article_url

    def fetch_url(self, info):
        return self.fetch_url

    def summary_url(self, info):
        return self.summary_url



# -*- coding: utf-8 -*-
from django_filters.rest_framework import DjangoFilterBackend
from rest_framework import viewsets
from rest_framework.filters import SearchFilter

from . import filters, models, serializers


class ArticleViewSet(viewsets.ModelViewSet):
    """ViewSet for viewing and editing Articles."""

    queryset = models.Article.objects.fast()
    serializer_class = serializers.ArticleSerializer
    filter_backends = (DjangoFilterBackend, SearchFilter)
    filter_class = filters.ArticleFilter
    search_fields = ('description', )
